signhash
========

.. image:: https://img.shields.io/pypi/pyversions/signhash.svg
    :target: https://pypi.python.org/pypi/signhash
    :alt: Latest PyPI version

.. image:: .png
   :target: 
   :alt: Latest Travis CI build status

SignHash for Python

Usage
-----

Installation
------------
